#ifndef __ADC_H__
#define __ADC_H__
#include <stdio.h>
#include <stdint.h>
#include "common.h"

#define ADC_Start_Cmp                           ((uint8_t)0x80)       
#define ADC_Enable                              ((uint8_t)0x01) 

#define ADCCH0		0X00
#define ADCCH1		0X01
#define ADCCH2		0X02

typedef enum
{
	ADCSynch	  = 0,	
	ADCASynch	  = 1 << 8,		//asynch trigger

} ADCTRGSelect_TypeDef;

typedef enum
{
	ADCTRGSingle	  = 0,	
	ADCTRGDouble	  = 1 << 7,	
} ADCTRGMode_TypeDef;


typedef enum
{
	ADC_Mode_SingleScan  		= 0x00,  
	ADC_Mode_GroupScan   		= 0x01 << 13,
	ADC_Mode_ContinueScan   = 0x02 << 13,
}ADC_Mode_t;
#define IS_ADC_MODE(MODE)			((MODE == ADC_Mode_SingleScan) || (MODE == ADC_Mode_GroupScan)\
                               || (MODE == ADC_Mode_ContinueScan))\

typedef enum
{
	ADC_ExternalTrig_Software = 0x00,	
	ADC_ExternalTrig_Synch    = 0x01,		//internal register
	ADC_ExternalTrig_Asynch   = 0x02,		//external trigger PIN
}ADC_ExternalTrigConv_t;
#define IS_ADC_TRIGGER(trig)		( (trig == ADC_ExternalTrig_Software)   	|| \
																	(trig == ADC_ExternalTrig_Synch)|| \
																	(trig == ADC_ExternalTrig_Asynch) )
typedef enum
{
    ADTES_Normal = 0U,      /* normal */
    ADTES_Zero_Code = 1U,   /* zero code test */
    ADTES_Half_Code = 3U,   /* half code test */
    ADTES_Full_Code = 5U,   /* full code test */
} ADC_Test_t;

  
#define   ADC_Channel_AN000   1<< 0    //PA00
#define  	ADC_Channel_AN001   1<< 1    //PA01
#define  	ADC_Channel_AN002   1<< 2    //PA02
#define  	ADC_Channel_AN003   1<< 3    //PA11
#define  	ADC_Channel_AN004   1<< 4    //PB13
#define  	ADC_Channel_AN005   1<< 5    //PB14
#define  	ADC_Channel_AN006   1<< 6    //PB15
#define  	ADC_Channel_AN007   1<< 7    //PB08

#define  	ADC_Channel_AN100   1<< 0    //PA03
#define  	ADC_Channel_AN101   1<< 1    //PA04
#define  	ADC_Channel_AN102   1<< 2    //PA05
#define  	ADC_Channel_AN103   1<< 3    //PA12
#define  	ADC_Channel_AN104   1<< 4    //PB06
#define  	ADC_Channel_AN105   1<< 5    //PB07
#define  	ADC_Channel_AN106   1<< 6    //PB00
#define  	ADC_Channel_AN107   1<< 7    //PB05

#define  	ADC_Channel_AN200   1<< 0    //PA06
#define  	ADC_Channel_AN201   1<< 1    //PA07
#define  	ADC_Channel_AN202   1<< 2    //PA08
#define  	ADC_Channel_AN203   1<< 3    //PA09
#define  	ADC_Channel_AN204   1<< 4    //PA10
#define  	ADC_Channel_AN205   1<< 5    //PA13
#define  	ADC_Channel_AN206   1<< 6    //PA14
#define  	ADC_Channel_AN207   1<< 7    //PA15
#define  	ADC_Channel_AN208   1<< 8    //PB09
#define  	ADC_Channel_AN209   1<< 9    //PB12
#define  	ADC_Channel_AN210   1<< 10    //PB11
#define  	ADC_Channel_AN211   1<< 11    //PB10
#define  	ADC_Channel_AN212   1<< 12    //PB01
#define  	ADC_Channel_AN213   1<< 13    //PB02
#define  	ADC_Channel_AN214   1<< 14    //PB03
#define  	ADC_Channel_AN215   1<< 15    //PB04

#define  	ADC_Channel_PGA00   1<< 0    //PGA00 out to UINT0

#define  	ADC_Channel_PGA10   1<< 0    //PGA10 out to UINT1
#define  	ADC_Channel_PGA11   1<< 1    //PGA11 out to UINT1
#define  	ADC_Channel_PGA12   1<< 2    //PGA12 out to UINT1

#define  	ADC_Channel_VRef    1<< 0    //internal ref in UINT2
#define  	ADC_Channel_Temp    1<< 1    //temperature in UINT2


typedef enum
{    
	
	ADCChannel_AN000 =  1<< 0,    //PA00	
	ADCChannel_AN001 =  1<< 1,    //PA01	
	ADCChannel_AN002 =  1<< 2 ,   //PA02	
	ADCChannel_AN003 =  1<< 3,    //PA11	
	ADCChannel_AN004 =  1<< 4,    //PB13	
	ADCChannel_AN005 =  1<< 5,    //PB14	
	ADCChannel_AN006 =  1<< 6,    //PB15	
	ADCChannel_AN007 =  1<< 7,    //PB08	
		
	ADCChannel_AN100 =  1<< 0,    //PA03	
	ADCChannel_AN101 =  1<< 1,    //PA04	
	ADCChannel_AN102 =  1<< 2,    //PA05	
	ADCChannel_AN103 =  1<< 3,    //PA12	
	ADCChannel_AN104 =  1<< 4,    //PB06	
	ADCChannel_AN105 =  1<< 5,    //PB07	
	ADCChannel_AN106 =  1<< 6,   //PB00	
	ADCChannel_AN107 =  1<< 7,    //PB05	
		
	ADCChannel_AN200 =  1<< 0,    //PA06	
	ADCChannel_AN201 =  1<< 1,    //PA07	
	ADCChannel_AN202 =  1<< 2,    //PA08	
	ADCChannel_AN203 =  1<< 3,    //PA09	
	ADCChannel_AN204 =  1<< 4 ,   //PA10	
	ADCChannel_AN205 =  1<< 5,    //PA13	
	ADCChannel_AN206 =  1<< 6,    //PA14	
	ADCChannel_AN207 =  1<< 7,    //PA15	
	ADCChannel_AN208 =  1<< 8,    //PB09	
	ADCChannel_AN209 =  1<< 9,    //PB12	
	ADCChannel_AN210 =  1<< 10,    //PB11	
	ADCChannel_AN211 =  1<< 11,    //PB10	
	ADCChannel_AN212 =  1<< 12 ,   //PB01	
	ADCChannel_AN213 =  1<< 13,    //PB02	
	ADCChannel_AN214 =  1<< 14,    //PB03	
	ADCChannel_AN215 =  1<< 15 ,   //PB04	
		
//	ADCChannel_PGA00 =  1<< 0,    //PGA00 out to UINT0	
//		
//	ADCChannel_PGA10 =  1<< 0 ,   //PGA10 out to UINT1	
//	ADCChannel_PGA11 =  1<< 1,    //PGA11 out to UINT1	
//	ADCChannel_PGA12 =  1<< 2,    //PGA12 out to UINT1	
		
	ADCChannel_VRef  =  0<< 0,    //internal ref in UINT2	
	ADCChannel_Temp  =  0<< 0,    //temperature in UINT2		
	
} ADC_Channel_t;
#define IS_SCAN_START_CHAN(CHAN)			(CHAN <= ADCChannel_AN215)

typedef enum 
{
	ADC_BScanInt_Disable = 0x00,       //group B scan interrupt disable
	ADC_BScanInt_Enable = 1 << 6,   //group B scan interrupt enable
} ADC_BScanInt_t;

typedef enum 
{
	ADC_ScanInt_disable = 0x00, 			//ADC convert complet interrupt disable
	ADC_ScanInt_Ensable = 0x01 << 12,	//ADC convert complet interrupt enable
} ADC_ScanInt_t;

typedef enum 
{
	ADC_AccEqual_disable = 0x00, //ADC convert result ACC/EQUAL disable
	ADC_AccEqual_Ensable = 0x01  //ADC convert result ACC/EQUAL enable
} ADC_AccEqualMode_t;

typedef enum 
{
	ADC_RstACCNum_1   = 0x00, //ADC result ACC select 1
	ADC_RstACCNum_2   = 0x01, //ADC result ACC select 2
	ADC_RstACCNum_3   = 0x02, //ADC result ACC select 3
	ADC_RstACCNum_4   = 0x03, //ADC result ACC select 4
	ADC_RstACCNum_16  = 0x05, //ADC result ACC select 16
	
} ADC_ACCEqulNum_t;

typedef enum 
{
	ADC_ACC_Enable    = 0x00, 			//ADC result select ACC
	ADC_Equal_Ensable = 0x01 << 7, 	//ADC result select Equal 
} ADC_EqualACCS_t;

typedef enum 
{
	ADC_AutoClear_Disable    = 0x00, 				//ADC result register Auto clear disable
	ADC_AutoClear_Ensable    = 0x01 << 5,  	//ADC result register Auto clear enable
} ADC_RstAutoClear_t;

typedef enum 
{
	ADC_Format_right    = 0x00, 				//ADC result Right-aligned
	ADC_Format_left     = 0x01 << 15,  	//ADC result Left-aligned
} ADC_Format_t;

typedef enum 
{
	ADC_GABSynch_ELSR04    		= 0x01, //ADC synch trigger source by ELSR04
	ADC_GABSynch_ELSR05    		= 0x02, //ADC synch trigger source by ELSR05
	ADC_GABSynch_ELSR06    		= 0x03, //ADC synch trigger source by ELSR06
	ADC_GABSynch_ELSR07    		= 0x04, //ADC synch trigger source by ELSR07
	ADC_GABSynch_ELSR08    		= 0x05, //ADC synch trigger source by ELSR08
	ADC_GABSynch_ELSR09    		= 0x06, //ADC synch trigger source by ELSR09
	ADC_GABSynch_ELSR10   		= 0x07, //ADC synch trigger source by ELSR10
	ADC_GABSynch_ELSR11  		  = 0x08, //ADC synch trigger source by ELSR11
	ADC_GABSynch_ELSR12       = 0x09, //ADC synch trigger source by ELSR12
	ADC_GABSynch_ELSR4or5     = 0x19, //ADC synch trigger source by ELSR04 or ELSR05
	ADC_GABSynch_ELSR6or7     = 0x1a, //ADC synch trigger source by ELSR06 or ELSR07
	ADC_GABSynch_ELSR8or9     = 0x1b, //ADC synch trigger source by ELSR08 or ELSR09
	ADC_GABSynch_ELSR10or11   = 0x1c, //ADC synch trigger source by ELSR10 or ELSR11
	ADC_GABSynch_NONE				  = 0x3f, //no trigger source
} ADC_GABSynchTrigSlt_t;

typedef enum 
{
	ADC_GCCtrl_Disable    = 0x00, 			//ADC group C disable
	ADC_GCCtrl_Enable     = 0x01 << 7,  //ADC group C enable
} ADC_GCCtrl_t;

typedef enum 
{
	ADC_CScanInt_Disable = 0x00, 			//group C scan interrupt disable
	ADC_CScanInt_Enable = 0x01 << 6,  //group C scan interrupt enable
} ADC_GCScanInt_t;

typedef enum 
{
	ADC_GCTrgS_MTU0RA = 0x01, 		//group C trigger source select MTU0.TGRA
	ADC_GCTrgS_MTU1RA = 0x02, 		//group C trigger source select MTU1.TGRA
	ADC_GCTrgS_MTU2RA = 0x03, 		//group C trigger source select MTU2.TGRA
	ADC_GCTrgS_MTU3RA = 0x04, 		//group C trigger source select MTU3.TGRA
	ADC_GCTrgS_MTU4RA = 0x05, 		//group C trigger source select MTU4.TGRA
	ADC_GCTrgS_MTU6RA = 0x06, 		//group C trigger source select MTU6.TGRA
	ADC_GCTrgS_MTU7RA = 0x07, 		//group C trigger source select MTU7.TGRA
	ADC_GCTrgS_MTU0RE = 0x08, 		//group C trigger source select MTU0.TGRE
	ADC_GCTrgS_MTU4RATC = 0x09, 	//group C trigger source select MTU4.TADCORA or MTU4.TCNT 
	ADC_GCTrgS_MTU0RAGE = 0x19, 	//group C trigger source select MTU0.TGRA or TGRE
	ADC_GCTrgS_MTU9RARE = 0x1A, 	//group C trigger source select MTU9.TGRA orMTU9.TGRE
	ADC_GCTrgS_MTU0RA9RA = 0x1B, 	//group C trigger source select MTU0.TGRA or MTU9.TGRA
	ADC_GCTrgS_MTU0RE9RE = 0x1C, 	//group C trigger source select MTU0.TGRE or MTU9.TGRE
	ADC_GCTrgS_Cancel = 0x3F, 		//group C trigger source Cancel
} ADC_GCTrigSrc_t;

typedef struct
{
	ADC_Mode_t ADC_Mode;						/*!< Configures the ADC to operate in select or scan mode. 
												 This parameter can be a value of @ref ADC_mode */											   
	
	ADCTRGMode_TypeDef ADC_TrigMode;    /*!< Select the trigger mode .
	                                           This parameter can be a value of @ref ADCTRGMode_TypeDef  */
	
	ADC_ExternalTrigConv_t ADC_ExternalTrigConv;    /*!< Select the external event used to trigger the start of conversion of a regular group.
	                                           This parameter can be a value of @ref ADC_ExternalTrigConv_t for regular channels conversion */
	
	ADCTRGSelect_TypeDef ADC_TRGSynchSelect;	/*!< Select the synch or asynch trigger mode.*/
	
	ADC_Channel_t ADC_AChannelSelect;	/*!< Select the ADC group A channel.*/
	
	ADC_Channel_t ADC_BChannelSelect;	/*!< Select the ADC group B channel.*/
	
	ADC_Channel_t ADC_CChannelSelect;	/*!< Select the ADC group C channel.*/
	
	ADC_BScanInt_t ADC_BScanInt;					/*!< Select the adc scan group B scan status.*/
		
	ADC_ScanInt_t ADC_ScanIntStatus; 				  /*!< Select the adc convert interrupt status.*/
	
	ADC_AccEqualMode_t ADC_AccEqualStatus;    /*!< Select the adc convert result equal status.*/
	
	ADC_ACCEqulNum_t ADC_ACCEqualNum;         /*!< Select the adc convert result ACC number.*/
	
	ADC_RstAutoClear_t ADC_RstAutoClear;      /*!< Select the adc convert result register auto clear status.*/
	
	ADC_Format_t ADC_TransFormat;     			  /*!< Select the adc convert result format.*/
	
	ADC_GABSynchTrigSlt_t ADC_GASynchTrgSource;     			  /*!< Select the adc group A synch trig source.*/
	ADC_GABSynchTrigSlt_t ADC_GBSynchTrgSource;     			  /*!< Select the adc group B synch trig source.*/
	
	ADC_GCCtrl_t ADC_GCCtrl;     			  /*!< Control ADC the group C work.*/
	
	ADC_GCScanInt_t ADC_CScanInt;					/*!< Select the adc scan group C scan status.*/						  

	ADC_GCTrigSrc_t ADC_GCTrigSrc;				/*!< Select the adc scan group C trigger source.*/				
	
	uint8_t ADC_SamplingTimCtrl;			 /*!< Configures the ADC sampling keep time.*/ 				  
}ADC_InitTypeDef;

typedef enum 
{	
	ADC_GroupPriority_Disable = 0, 				//group priority control disable
	ADC_GroupPriority_Enable = 1 , 				//group priority control enable
} ADC_GroupPrioritySet_t;

typedef enum 
{	
	ADC_GScanRstart_Disable = 0, 				//low priority group do not need restart after interrupt
	ADC_GScanRstart_Enable = 1 << 1, 		//low priority group need restart after interrupt
} ADC_GroupScanRstart_t;

typedef enum 
{	
	ADC_GScanRstartCh_First = 0, 						//low priority group restart from first channel
	ADC_GScanRstartCh_BrkChan = 1 << 14, 		//low priority group restart from break channel
} ADC_GScanRstartCh_t;

typedef enum 
{	
	ADC_GScanMode_Normal = 0, 						//low priority group scan mode normal
	ADC_GScanMode_Continue = 1 << 15, 		//low priority group scan continuously
} ADC_GScanMode_t;

typedef struct
{
	ADC_GroupPrioritySet_t ADC_GPrioritySet;					/*!< Configures the group priority enable.*/ 
												 
	ADC_GroupScanRstart_t ADC_GScanRstart;						/*!< Configures the low priority group restart. 
																										This parameter can be a value of @ref ADC_GScanRstart_Disable */	
	ADC_GScanRstartCh_t ADC_GScanRSCh;								/*!< Configures the low priority group restart channel.*/ 
 		
  ADC_GScanMode_t ADC_GScanRSMode;							/*!< Configures the low priority group Scan mode.*/ 
}ADC_GroupScanTypeDef;

typedef enum 
{	
	ADC_ADCPGA_Mult = 0, 						//ADC PGA use PGA amplify
	ADC_ADCPGA_Pass = 1, 						//ADC PGA use PGA channel only
} ADC_ADCPGAMod_t;

typedef enum 
{	
	ADC_ADCPGA_CH0 = 0, 						//ADC PGA channel 0
	ADC_ADCPGA_CH1 = 1, 						//ADC PGA channel 1
	ADC_ADCPGA_CH2 = 2, 						//ADC PGA channel 2
} ADC_ADCPGAChannel_t;

#define IS_ADCPGA_Channel(UNITx,CHANN)			(if((UNITx == ADC0)&&(CHANN < ADC_ADCPGA_CH1)) \
	                                        || if((UNITx == ADC1)&&(CHANN <= ADC_ADCPGA_CH2))) \


#define ADC_ADPGAGS_2000			 0x00				//ADC amplify 2.0
#define ADC_ADPGAGS_2500			 0x01				//ADC amplify 2.5
#define ADC_ADPGAGS_3077			 0x04				//ADC amplify 3.077
#define ADC_ADPGAGS_3636			 0x06				//ADC amplify 3.636
#define ADC_ADPGAGS_4000			 0x07				//ADC amplify 4.0
#define ADC_ADPGAGS_4444			 0x08				//ADC amplify 4.444

#define ADC_TempACC_Enable			 0x01				//ADC temperature sensor ACC enable
#define ADC_TempACC_Disable			 0x00				//ADC temperature sensor ACC disable

#define ADC_InterRef_Enable			 0x02				//ADC temperature sensor internal refer voltage enable
#define ADC_InterRef_Disable		 0x00				//ADC temperature sensor internal refer voltage disable																					
																					
void ADC_Init(ADC_Type * ADCx,ADC_InitTypeDef* ADC_InitStruct);
void ADC_Start(ADC_Type * ADCx);
void ADC_Stop(ADC_Type * ADCx);
/**
  * @brief  Set the sample status value
  * @param  ADCx: ADC unit 0~2 
  * @param  ChanNUM: ADC channel for set status value
*           Uint0-1: channel--0, 1,2,3,16
*           Uint2:   channel--0,1,2,3,4,5,6,7,8,9,10,11 and internal Ref 
  * @param  StaValue: the value for sample status
  * @retval None
  */
void ADC_SampleStatus(ADC_Type * ADCx, uint8_t ChanNUM, uint8_t StaValue);

/**
  * @brief  Set the sample status value
  * @param  ADCx: ADC unit 0~2 
  * @param  ADC_GSInitStruct: ADC group scan set parameter
  * @retval None
  */
void ADC_GScan_Init(ADC_Type * ADCx, ADC_GroupScanTypeDef* ADC_GSInitStruct);

/************************************************************************************
  * @brief  Set the ADC PGA multiple
  * @param  ADCx: ADC unit 0~2 
  * @param  AdcPgaCh: ADC PGA channel
*											ADC_ADCPGA_CH0: channel 0 for ADC0/ADC1
*											ADC_ADCPGA_CH1: channel 1 for ADC1
*											ADC_ADCPGA_CH2: channel 2 for ADC1
  * @param  PgaStatus: 
*                     ENABLE
*                     DISABLE
  * @param  PgaMult: PGA multiple
*										ADC_ADPGAGS_2000: ADC amplify 2.0
*										ADC_ADPGAGS_2500: ADC amplify 2.5
*										ADC_ADPGAGS_3077: ADC amplify 3.077
*										ADC_ADPGAGS_3636: ADC amplify 3.636
*										ADC_ADPGAGS_4000: ADC amplify 4.0
*										ADC_ADPGAGS_4444: ADC amplify 4.444
  * @retval None
  ************************************************************************************/
void ADCx_PGA_Init(ADC_Type * ADCx, ADC_ADCPGAChannel_t adcpgach,uint8_t PgaStatus,uint8_t PgaMult);

/**
  * @brief  enable ADC Temprature sensor.
* @param  	ACCStat: ADC channel
*                  ADC_TempACC_Enable: enable ACC and average
*                  ADC_TempACC_Disable: disable ACC and average
  * @retval None
  */
void ADCTemperature_Enable(uint8_t ACCStat);

/**
  * @brief  disable ADC Temprature sensor.
* @param  	none
  * @retval None
  */
void ADCTemperature_Disable(void);

/**
  * @brief  enable ADC internal ref voltage transfer.
* @param  	ACCStat: ADC channel
*                  ADC_InterRef_Enable: enable ACC and average
*                  ADC_InterRef_Disable: disable ACC and average
  * @retval None
  */
void ADCInterRefVol_Enable(uint8_t ACCStat);

/**
  * @brief  disable the ADC internal ref voltage transfer.
* @param  	none
  * @retval None
  */
void ADCInterRefVol_Disable(void);

#endif

