#include "isr.h"
volatile uint32_t g_ticks = 0xFFFFFFFFU;

ATE_FRAME_t pData;
ISR_InitTypeDef_t IRQ_Fun;

/**
  * @brief  SysTick Handler Decreament the g_ticks value
  * @param  TM13 IRQ
  * @retval None
  */
void SysTick_Handler(void)
{
	g_ticks--;
}

/**
  * @brief  IRQ00_Handler
  * @param  LVI IRQ
  * @retval None
  */
void IRQ0_Handler(void)
{
	IRQ_Fun.IRQ[LVI_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ01_Handler
  * @param  INTP0 IRQ
  * @retval None
  */
void IRQ1_Handler(void)
{
	IRQ_Fun.IRQ[WDT0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ02_Handler
  * @param  INTP1 IRQ
  * @retval None
  */
void IRQ2_Handler(void)
{
	IRQ_Fun.IRQ[WDT1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ03_Handler
  * @param  INTP2 IRQ
  * @retval None
  */
void IRQ3_Handler(void)
{
	IRQ_Fun.IRQ[INTP0_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ04_Handler
  * @param  INTP3 IRQ
  * @retval None
  */
void IRQ4_Handler(void)
{
	IRQ_Fun.IRQ[INTP1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ05_Handler
  * @param  INTTM01H IRQ
  * @retval None
  */
void IRQ5_Handler(void)
{
	IRQ_Fun.IRQ[INTP2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ06_Handler
  * @param  KEY IRQ
  * @retval None
  */
void IRQ6_Handler(void)
{
	IRQ_Fun.IRQ[INTP3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ07_Handler
  * @param  ST2/SPI20/IIC20 IRQ 
  * @retval None
  */
void IRQ7_Handler(void)
{
	IRQ_Fun.IRQ[INTP4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ08_Handler
  * @param  SR2/SPI21/IIC21 IRQ
  * @retval None
  */
void IRQ8_Handler(void)
{	
	IRQ_Fun.IRQ[INTP5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ09_Handler
  * @param  INTP6 IRQ
  * @retval None
  */
void IRQ9_Handler(void)
{
	IRQ_Fun.IRQ[INTP6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ10_Handler
  * @param  INTP7 IRQ
  * @retval None
  */
void IRQ10_Handler(void)
{
	IRQ_Fun.IRQ[INTP7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ11_Handler
  * @param  ST0_IRQn/SPI00_IRQn/IIC00_IRQn  
  * @note   the num of ST0_IRQn is same as SPI00_IRQn and IIC00_IRQ, so SPI00_IRQn or IIC00_IRQ
  *			interrupt quote this function handler IRQ10_Handler
  * @retval None
  */
void IRQ11_Handler(void)
{
	IRQ_Fun.IRQ[ST0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ12_Handler
  * @param  SR0_IRQn/SPI01_IRQn/IIC01_IRQn 
  * @note   the num of SR0_IRQn is same as SPI01_IRQn and IIC01_IRQ, so SPI01_IRQn or IIC01_IRQ
  *			interrupt quote this function handler IRQ11_Handler
  * @retval None
  */
void IRQ12_Handler(void)
{
	IRQ_Fun.IRQ[SR0_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ13_Handler
  * @param   INTSRE0 
  * @note   None
  * @retval None
  */
void IRQ13_Handler(void)
{
	IRQ_Fun.IRQ[SRE0_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ14_Handler
  * @param   ST1_IRQn/SPI10_IRQn/IIC10_IRQn 
  * @note   the num of SRE0_IRQn is same as TM01H_IRQn, so TM01H_IRQn 
  *			interrupt quotes this function handler IRQ12_Handler
  * @retval None
  */
void IRQ14_Handler(void)
{
	IRQ_Fun.IRQ[ST1_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ15_Handler
  * @param  SR1_IRQn/SPI11_IRQn/IIC11_IRQn  
  * @note   the num of ST1_IRQn is same as SPI10_IRQn and IIC10_IRQ, so SPI10_IRQn or IIC10_IRQ
  *			interrupt quote this function handler IRQ13_Handler
  * @retval None
  */
void IRQ15_Handler(void)
{
	IRQ_Fun.IRQ[SR1_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ16_Handler
  * @param   INTSRE0 
  * @note   None
  * @retval None
  */
void IRQ16_Handler(void)
{
	IRQ_Fun.IRQ[SRE1_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ17_Handler
  * @param  ST2_IRQn/SPI20_IRQn/IIC20_IRQn
  * @note   the num of SR1_IRQn is same as SPI11_IRQn and IIC11_IRQ, so SPI11_IRQn or IIC11_IRQ
  *			interrupt quote this function handler IRQ14_Handler
  * @retval None
  */
void IRQ17_Handler(void)
{
	IRQ_Fun.IRQ[ST2_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ18_Handler
  * @param  SR2_IRQn/SPI21_IRQn/IIC21_IRQn
  * @retval None
  */
void IRQ18_Handler(void)
{
	IRQ_Fun.IRQ[SR2_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ19_Handler
  * @param   INTSRE0 
  * @note   None
  * @retval None
  */
void IRQ19_Handler(void)
{
	IRQ_Fun.IRQ[SRE2_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ20_Handler
  * @param  ST3_IRQn/SPI30_IRQn/IIC20_IRQn
  * @note   the num of ST3_IRQn is same as SPI30_IRQn and IIC30_IRQ, so SPI30_IRQn or IIC30_IRQ
  *			interrupt quote this function handler IRQ20_Handler
  * @retval None
  */
void IRQ20_Handler(void)
{
	IRQ_Fun.IRQ[ST3_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ21_Handler
  * @param  SR3_IRQn/SPI31_IRQn/IIC31_IRQn
  * @retval None
  */
void IRQ21_Handler(void)
{
	IRQ_Fun.IRQ[SR3_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ22_Handler
  * @param   INTSRE3 
  * @note   None
  * @retval None
  */
void IRQ22_Handler(void)
{
	IRQ_Fun.IRQ[SRE3_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ23_Handler
  * @param  IICA0_IRQn
  * @retval None
  */
void IRQ23_Handler(void)
{
	IRQ_Fun.IRQ[IICA0_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ24_Handler
  * @param  IICA1_IRQn
  * @retval None
  */
void IRQ24_Handler(void)
{
	IRQ_Fun.IRQ[IICA1_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ25_Handler
  * @param  SPI0_IRQn
  * @retval None
  */
void IRQ25_Handler(void)
{
	IRQ_Fun.IRQ[SPI0_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ26_Handler
  * @param  SPI1_IRQn
  * @retval None
  */
void IRQ26_Handler(void)
{
	IRQ_Fun.IRQ[SPI1_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ27_Handler
  * @param  TM00_IRQn
  * @retval None
  */
void IRQ27_Handler(void)
{
	IRQ_Fun.IRQ[TM00_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ28_Handler
  * @param  TM01_IRQn
  * @retval None
  */
void IRQ28_Handler(void)
{
	IRQ_Fun.IRQ[TM01_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ29_Handler
  * @param  TM02_IRQn
  * @retval None
  */
void IRQ29_Handler(void)
{
	IRQ_Fun.IRQ[TM02_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ30_Handler
  * @param  TM03_IRQn
  * @retval None
  */
void IRQ30_Handler(void)
{
	IRQ_Fun.IRQ[TM03_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ31_Handler
  * @param  TM04_IRQn
  * @retval None
  */
void IRQ31_Handler(void)
{
	IRQ_Fun.IRQ[TM04_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ32_Handler
  * @param  TM05_IRQn
  * @retval None
  */
void IRQ32_Handler(void)
{
	IRQ_Fun.IRQ[TM05_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ33_Handler
  * @param  TM06_IRQn
  * @retval None
  */
void IRQ33_Handler(void)
{
	IRQ_Fun.IRQ[TM06_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ34_Handler
  * @param  TM07_IRQn
  * @retval None
  */
void IRQ34_Handler(void)
{
	IRQ_Fun.IRQ[TM07_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ35_Handler
  * @param  TM01H_IRQn
  * @retval None
  */
void IRQ35_Handler(void)
{
	IRQ_Fun.IRQ[TM01H_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ36_Handler
  * @param  TM03H_IRQn
  * @retval None
  */
void IRQ36_Handler(void)
{
	IRQ_Fun.IRQ[TM03H_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ37_Handler
  * @param  TM10_IRQn
  * @retval None
  */
void IRQ37_Handler(void)
{
	IRQ_Fun.IRQ[TM10_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ38_Handler
  * @param  TM11_IRQn
  * @retval None
  */
void IRQ38_Handler(void)
{
	IRQ_Fun.IRQ[TM11_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ39_Handler
  * @param  TM12_IRQn
  * @retval None
  */
void IRQ39_Handler(void)
{
	IRQ_Fun.IRQ[TM12_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ40_Handler
  * @param  TM13_IRQn
  * @retval None
  */
void IRQ40_Handler(void)
{
	IRQ_Fun.IRQ[TM13_IRQn].intHandle(&pData);	
}
/**
  * @brief  IRQ41_Handler
  * @param  TM14_IRQn
  * @retval None
  */
void IRQ41_Handler(void)
{
	IRQ_Fun.IRQ[TM14_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ42_Handler
  * @param  TM15_IRQn
  * @retval None
  */
void IRQ42_Handler(void)
{
	IRQ_Fun.IRQ[TM15_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ43_Handler
  * @param  TM16_IRQn
  * @retval None
  */
void IRQ43_Handler(void)
{
	IRQ_Fun.IRQ[TM16_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ44_Handler
  * @param  TM17_IRQn
  * @retval None
  */
void IRQ44_Handler(void)
{
	IRQ_Fun.IRQ[TM17_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ45_Handler
  * @param  TM11H_IRQn
  * @retval None
  */
void IRQ45_Handler(void)
{
	IRQ_Fun.IRQ[TM11H_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ46_Handler
  * @param  TM11H_IRQn
  * @retval None
  */
void IRQ46_Handler(void)
{
	IRQ_Fun.IRQ[TM13H_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ47_Handler
  * @param  ADC0_IRQn
  * @retval None
  */
void IRQ47_Handler(void)
{
	IRQ_Fun.IRQ[ADC0_ADIREQ_N_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ48_Handler
  * @param  ADC1_IRQn
  * @retval None
  */
void IRQ48_Handler(void)
{
	IRQ_Fun.IRQ[ADC1_ADIREQ_N_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ49_Handler
  * @param  ADC2_IRQn
  * @retval None
  */
void IRQ49_Handler(void)
{
	IRQ_Fun.IRQ[ADC2_ADIREQ_N_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ50_Handler
  * @param  ADC0_GBADIREQ_N_IRQn
  * @retval None
  */
void IRQ50_Handler(void)
{
	IRQ_Fun.IRQ[ADC0_GBADIREQ_N_IRQn].intHandle(&pData);	
}
/**
  * @brief  IRQ51_Handler
  * @param  ADC1_GBADIREQ_N_IRQn
  * @retval None
  */
void IRQ51_Handler(void)
{
	IRQ_Fun.IRQ[ADC1_GBADIREQ_N_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ52_Handler
  * @param  ADC2_GBADIREQ_N_IRQn
  * @retval None
  */
void IRQ52_Handler(void)
{
	IRQ_Fun.IRQ[ADC2_GBADIREQ_N_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ53_Handler
  * @param  ADC0_GCADIREQ_N_IRQn
  * @retval None
  */
void IRQ53_Handler(void)
{
	IRQ_Fun.IRQ[ADC0_GCADIREQ_N_IRQn].intHandle(&pData);	
}
/**
  * @brief  IRQ54_Handler
  * @param  ADC1_GCADIREQ_N_IRQn
  * @retval None
  */
void IRQ54_Handler(void)
{
	IRQ_Fun.IRQ[ADC1_GCADIREQ_N_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ55_Handler
  * @param  ADC2_GCADIREQ_N_IRQn
  * @retval None
  */
void IRQ55_Handler(void)
{
	IRQ_Fun.IRQ[ADC2_GCADIREQ_N_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ56_Handler
  * @param  RTC_IRQn
  * @retval None
  */
void IRQ56_Handler(void)
{
	IRQ_Fun.IRQ[RTC_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ57_Handler
  * @param  IT_IRQn
  * @retval None
  */
void IRQ57_Handler(void)
{
	IRQ_Fun.IRQ[IT_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ58_Handler
  * @param  KR_IRQn
  * @retval None
  */
void IRQ58_Handler(void)
{
	IRQ_Fun.IRQ[KR_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ59_Handler
  * @param  CMP0_IRQn
  * @retval None
  */
void IRQ59_Handler(void)
{
	IRQ_Fun.IRQ[CMP0_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ60_Handler
  * @param  CMP1_IRQn  
  * @retval None
  */
void IRQ60_Handler(void)
{
	IRQ_Fun.IRQ[CMP1_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ61_Handler
  * @param  CMP2_IRQn  
  * @retval None
  */
void IRQ61_Handler(void)
{
	IRQ_Fun.IRQ[CMP2_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ62_Handler
  * @param  CMP3_IRQn  
  * @retval None
  */
void IRQ62_Handler(void)
{
	IRQ_Fun.IRQ[CMP3_IRQn].intHandle(&pData);	
}

/**
  * @brief  IRQ63_Handler
  * @param  C0ERR_IRQn 
  * @retval None
  */
void IRQ63_Handler(void)
{
	IRQ_Fun.IRQ[C0ERR_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ64_Handler
  * @param  C0REC_IRQn 
  * @retval None
  */
void IRQ64_Handler(void)
{
	IRQ_Fun.IRQ[C0REC_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ65_Handler
  * @param  C0WUP_IRQn 
  * @retval None
  */
void IRQ65_Handler(void)
{
	IRQ_Fun.IRQ[C0WUP_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ66_Handler
  * @param  C0TRX_IRQn 
  * @retval None
  */
void IRQ66_Handler(void)
{
	IRQ_Fun.IRQ[C0TRX_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ67_Handler
  * @param  LCDB_IRQn 
  * @retval None
  */
void IRQ67_Handler(void)
{
	IRQ_Fun.IRQ[LCDB_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ68_Handler
  * @param  QSPI_IRQn 
  * @retval None
  */
void IRQ68_Handler(void)
{
	IRQ_Fun.IRQ[QSPI_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ69_Handler
  * @param  QSPI_DMAREQ_IRQn 
  * @retval None
  */
void IRQ69_Handler(void)
{
	IRQ_Fun.IRQ[QSPI_DMAREQ_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ70_Handler
  * @param  FL_IRQn 
  * @retval None
  */
void IRQ70_Handler(void)
{
	IRQ_Fun.IRQ[FMC_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ71_Handler
  * @param  OSDC_IRQn 
  * @retval None
  */
void IRQ71_Handler(void)
{
	IRQ_Fun.IRQ[OSDC_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ72_Handler
  * @param  PGI0_IRQn 
  * @retval None
  */
void IRQ72_Handler(void)
{
	IRQ_Fun.IRQ[PGI0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ73_Handler
  * @param  PGI1_IRQn 
  * @retval None
  */
void IRQ73_Handler(void)
{
	IRQ_Fun.IRQ[PGI1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ74_Handler
  * @param  PGI2_IRQn 
  * @retval None
  */
void IRQ74_Handler(void)
{
	IRQ_Fun.IRQ[PGI2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ75_Handler
  * @param  PGI3_IRQn 
  * @retval None
  */
void IRQ75_Handler(void)
{
	IRQ_Fun.IRQ[PGI3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ76_Handler
  * @param  GPT0_ELCCMPA0_IRQn 
  * @retval None
  */
void IRQ76_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPA0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ77_Handler
  * @param  GPT0_ELCCMPB0_IRQn 
  * @retval None
  */
void IRQ77_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPB0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ78_Handler
  * @param  GPT0_ELCCMPC0_IRQn 
  * @retval None
  */
void IRQ78_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPC0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ79_Handler
  * @param  GPT0_ELCCMPD0_IRQn 
  * @retval None
  */
void IRQ79_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPD0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ80_Handler
  * @param  GPT0_ELCCMPE0_IRQn 
  * @retval None
  */
void IRQ80_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPE0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ81_Handler
  * @param  GPT0_ELCCMPF0_IRQn 
  * @retval None
  */
void IRQ81_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPF0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ82_Handler
  * @param  GPT0_ELCOVF0_IRQn 
  * @retval None
  */
void IRQ82_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCOVF0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ83_Handler
  * @param  GPT0_ELCUDF0_IRQn 
  * @retval None
  */
void IRQ83_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCUDF0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ84_Handler
  * @param  GPT0_ELCCMPA1_IRQn 
  * @retval None
  */
void IRQ84_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPA1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ85_Handler
  * @param  GPT0_ELCCMPB1_IRQn 
  * @retval None
  */
void IRQ85_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPB1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ86_Handler
  * @param  GPT0_ELCCMPC1_IRQn 
  * @retval None
  */
void IRQ86_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPC1_IRQn].intHandle(&pData);
}
/**
  * @brief  IRQ87_Handler
  * @param  GPT0_ELCCMPD1_IRQn 
  * @retval None
  */
void IRQ87_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPD1_IRQn].intHandle(&pData);
}
/**
  * @brief  IRQ88_Handler
  * @param  GPT0_ELCCMPE1_IRQn 
  * @retval None
  */
void IRQ88_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPE1_IRQn].intHandle(&pData);
}
/**
  * @brief  IRQ89_Handler
  * @param  GPT0_ELCCMPF1_IRQn 
  * @retval None
  */
void IRQ89_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPF1_IRQn].intHandle(&pData);
}
/**
  * @brief  IRQ90_Handler
  * @param  GPT0_ELCOVF1_IRQn 
  * @retval None
  */
void IRQ90_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCOVF1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ91_Handler
  * @param  GPT0_ELCUDF1_IRQn 
  * @retval None
  */
void IRQ91_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCUDF1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ92_Handler
  * @param  GPT0_ELCCMPA2_IRQn 
  * @retval None
  */
void IRQ92_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPA2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ93_Handler
  * @param  GPT0_ELCCMPB2_IRQn 
  * @retval None
  */
void IRQ93_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPB2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ94_Handler
  * @param  GPT0_ELCCMPC2_IRQn 
  * @retval None
  */
void IRQ94_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPC2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ95_Handler
  * @param  GPT0_ELCCMPD2_IRQn 
  * @retval None
  */
void IRQ95_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPD2_IRQn].intHandle(&pData);
}
/**
  * @brief  IRQ96_Handler
  * @param  GPT0_ELCCMPE2_IRQn 
  * @retval None
  */
void IRQ96_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPE2_IRQn].intHandle(&pData);
}
/**
  * @brief  IRQ97_Handler
  * @param  GPT0_ELCCMPF2_IRQn 
  * @retval None
  */
void IRQ97_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPF2_IRQn].intHandle(&pData);
}
/**
  * @brief  IRQ98_Handler
  * @param  GPT0_ELCOVF2_IRQn 
  * @retval None
  */
void IRQ98_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCOVF2_IRQn].intHandle(&pData);
}
/**
  * @brief  IRQ99_Handler
  * @param  GPT0_ELCUDF2_IRQn 
  * @retval None
  */
void IRQ99_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCUDF2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ100_Handler
  * @param  GPT0_ELCCMPA3_IRQn 
  * @retval None
  */
void IRQ100_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPA3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ101_Handler
  * @param  GPT0_ELCCMPB3_IRQn 
  * @retval None
  */
void IRQ101_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPB3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ102_Handler
  * @param  GPT0_ELCCMPC3_IRQn 
  * @retval None
  */
void IRQ102_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPC3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ103_Handler
  * @param  GPT0_ELCCMPD3_IRQn 
  * @retval None
  */
void IRQ103_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPD3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ104_Handler
  * @param  GPT0_ELCCMPE3_IRQn 
  * @retval None
  */
void IRQ104_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPE3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ105_Handler
  * @param  GPT0_ELCCMPF3_IRQn 
  * @retval None
  */
void IRQ105_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCCMPF3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ106_Handler
  * @param  GPT0_ELCOVF3_IRQn 
  * @retval None
  */
void IRQ106_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCOVF3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ107_Handler
  * @param  GPT0_ELCUDF3_IRQn 
  * @retval None
  */
void IRQ107_Handler(void)
{
	IRQ_Fun.IRQ[GPT0_ELCUDF3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ108_Handler
  * @param  GPT1_ELCCMPA0_IRQn 
  * @retval None
  */
void IRQ108_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPA0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ109_Handler
  * @param  GPT1_ELCCMPB0_IRQn 
  * @retval None
  */
void IRQ109_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPB0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ110_Handler
  * @param  GPT1_ELCCMPC0_IRQn 
  * @retval None
  */
void IRQ110_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPC0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ111_Handler
  * @param  GPT1_ELCCMPD0_IRQn 
  * @retval None
  */
void IRQ111_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPD0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ112_Handler
  * @param  GPT1_ELCCMPE0_IRQn 
  * @retval None
  */
void IRQ112_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPE0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ113_Handler
  * @param  GPT1_ELCCMPF0_IRQn 
  * @retval None
  */
void IRQ113_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPF0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ114_Handler
  * @param  GPT1_ELCOVF0_IRQn 
  * @retval None
  */
void IRQ114_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCOVF0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ115_Handler
  * @param  GPT1_ELCUDF0_IRQn 
  * @retval None
  */
void IRQ115_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCUDF0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ116_Handler
  * @param  GPT1_ELCCMPA1_IRQn 
  * @retval None
  */
void IRQ116_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPA1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ117_Handler
  * @param  GPT1_ELCCMPB1_IRQn 
  * @retval None
  */
void IRQ117_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPB1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ118_Handler
  * @param  GPT1_ELCCMPC1_IRQn 
  * @retval None
  */
void IRQ118_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPC1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ119_Handler
  * @param  GPT1_ELCCMPD1_IRQn 
  * @retval None
  */
void IRQ119_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPD1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ120_Handler
  * @param  GPT1_ELCCMPE1_IRQn 
  * @retval None
  */
void IRQ120_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPE1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ121_Handler
  * @param  GPT1_ELCCMPF1_IRQn 
  * @retval None
  */
void IRQ121_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPF1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ122_Handler
  * @param  GPT1_ELCOVF1_IRQn 
  * @retval None
  */
void IRQ122_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCOVF1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ123_Handler
  * @param  GPT1_ELCUDF1_IRQn 
  * @retval None
  */
void IRQ123_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCUDF1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ124_Handler
  * @param  GPT1_ELCCMPA2_IRQn 
  * @retval None
  */
void IRQ124_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPA2_IRQn].intHandle(&pData);
}
                      
/**
  * @brief  IRQ125_Handler
  * @param  GPT1_ELCCMPB2_IRQn 
  * @retval None
  */
void IRQ125_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPB2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ126_Handler
  * @param  GPT1_ELCCMPC2_IRQn 
  * @retval None
  */
void IRQ126_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPC2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ127_Handler
  * @param  GPT1_ELCCMPD2_IRQn 
  * @retval None
  */
void IRQ127_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPD2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ128_Handler
  * @param  GPT1_ELCCMPE2_IRQn 
  * @retval None
  */
void IRQ128_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPE2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ129_Handler
  * @param  GPT1_ELCCMPF2_IRQn 
  * @retval None
  */
void IRQ129_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPF2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ130_Handler
  * @param  GPT1_ELCOVF2_IRQn 
  * @retval None
  */
void IRQ130_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCOVF2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ131_Handler
  * @param  GPT1_ELCUDF2_IRQn 
  * @retval None
  */
void IRQ131_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCUDF2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ132_Handler
  * @param  GPT1_ELCCMPA3_IRQn 
  * @retval None
  */
void IRQ132_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPA3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ133_Handler
  * @param  GPT1_ELCCMPB3_IRQn 
  * @retval None
  */
void IRQ133_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPB3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ134_Handler
  * @param  GPT1_ELCCMPC3_IRQn 
  * @retval None
  */
void IRQ134_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPC3_IRQn].intHandle(&pData);
}
                        
/**
  * @brief  IRQ135_Handler
  * @param  GPT1_ELCCMPD3_IRQn 
  * @retval None
  */
void IRQ135_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPD3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ136_Handler
  * @param  GPT1_ELCCMPE3_IRQn 
  * @retval None
  */
void IRQ136_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPE3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ137_Handler
  * @param  GPT1_ELCCMPF3_IRQn 
  * @retval None
  */
void IRQ137_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPF3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ138_Handler
  * @param  GPT1_ELCOVF3_IRQn 
  * @retval None
  */
void IRQ138_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCOVF3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ139_Handler
  * @param  GPT1_ELCUDF3_IRQn 
  * @retval None
  */
void IRQ139_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCUDF3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ140_Handler
  * @param  GPT1_ELCCMPA4_IRQn 
  * @retval None
  */
void IRQ140_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPA4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ141_Handler
  * @param  GPT1_ELCCMPB4_IRQn 
  * @retval None
  */
void IRQ141_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPB4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ142_Handler
  * @param  GPT1_ELCCMPC4_IRQn 
  * @retval None
  */
void IRQ142_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPC4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ143_Handler
  * @param  GPT1_ELCCMPD4_IRQn 
  * @retval None
  */
void IRQ143_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPD4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ144_Handler
  * @param  GPT1_ELCCMPE4_IRQn 
  * @retval None
  */
void IRQ144_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPE4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ145_Handler
  * @param  GPT1_ELCCMPF4_IRQn 
  * @retval None
  */
void IRQ145_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPF4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ146_Handler
  * @param  GPT1_ELCOVF4_IRQn 
  * @retval None
  */
void IRQ146_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCOVF4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ147_Handler
  * @param  GPT1_ELCUDF4_IRQn 
  * @retval None
  */
void IRQ147_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCUDF4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ148_Handler
  * @param  GPT1_ELCCMPA5_IRQn 
  * @retval None
  */
void IRQ148_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPA5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ149_Handler
  * @param  GPT1_ELCCMPB5_IRQn 
  * @retval None
  */
void IRQ149_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPB5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ150_Handler
  * @param  GPT1_ELCCMPC5_IRQn 
  * @retval None
  */
void IRQ150_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPC5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ151_Handler
  * @param  GPT1_ELCCMPD5_IRQn 
  * @retval None
  */
void IRQ151_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPD5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ152_Handler
  * @param  GPT1_ELCCMPE5_IRQn 
  * @retval None
  */
void IRQ152_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPE5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ153_Handler
  * @param  GPT1_ELCCMPF5_IRQn 
  * @retval None
  */
void IRQ153_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPF5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ154_Handler
  * @param  GPT1_ELCOVF5_IRQn 
  * @retval None
  */
void IRQ154_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCOVF5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ155_Handler
  * @param  GPT1_ELCUDF5_IRQn 
  * @retval None
  */
void IRQ155_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCUDF5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ156_Handler
  * @param  GPT1_ELCCMPA6_IRQn 
  * @retval None
  */
void IRQ156_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPA6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ157_Handler
  * @param  GPT1_ELCCMPB6_IRQn 
  * @retval None
  */
void IRQ157_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPB6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ158_Handler
  * @param  GPT1_ELCCMPC6_IRQn 
  * @retval None
  */
void IRQ158_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPC6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ159_Handler
  * @param  GPT1_ELCCMPD6_IRQn 
  * @retval None
  */
void IRQ159_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPD6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ160_Handler
  * @param  GPT1_ELCCMPE6_IRQn 
  * @retval None
  */
void IRQ160_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPE6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ161_Handler
  * @param  GPT1_ELCCMPF6_IRQn 
  * @retval None
  */
void IRQ161_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPF6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ162_Handler
  * @param  GPT1_ELCOVF6_IRQn 
  * @retval None
  */
void IRQ162_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCOVF6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ163_Handler
  * @param  GPT1_ELCUDF6_IRQn 
  * @retval None
  */
void IRQ163_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCUDF6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ164_Handler
  * @param  GPT1_ELCCMPA7_IRQn 
  * @retval None
  */
void IRQ164_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPA7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ165_Handler
  * @param  GPT1_ELCCMPB7_IRQn 
  * @retval None
  */
void IRQ165_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPB7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ166_Handler
  * @param  GPT1_ELCCMPC7_IRQn 
  * @retval None
  */
void IRQ166_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPC7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ167_Handler
  * @param  GPT1_ELCCMPD7_IRQn 
  * @retval None
  */
void IRQ167_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPD7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ168_Handler
  * @param  GPT1_ELCCMPE7_IRQn 
  * @retval None
  */
void IRQ168_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPE7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ169_Handler
  * @param  GPT1_ELCCMPF7_IRQn 
  * @retval None
  */
void IRQ169_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCCMPF7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ170_Handler
  * @param  GPT1_ELCOVF7_IRQn 
  * @retval None
  */
void IRQ170_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCOVF7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ171_Handler
  * @param  GPT1_ELCUDF7_IRQn 
  * @retval None
  */
void IRQ171_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCUDF7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ172_Handler
  * @param  GPT1_ELCEDGUVW_IRQn 
  * @retval None
  */
void IRQ172_Handler(void)
{
	IRQ_Fun.IRQ[GPT1_ELCEDGUVW_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ173_Handler
  * @param  AES_WRREQ_IRQn 
  * @retval None
  */
void IRQ173_Handler(void)
{
	IRQ_Fun.IRQ[AES_WRREQ_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ174_Handler
  * @param  AES_RDREQ_IRQn 
  * @retval None
  */
void IRQ174_Handler(void)
{
	IRQ_Fun.IRQ[AES_RDREQ_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ175_Handler
  * @param  RNG_RDREQ_IRQn 
  * @retval None
  */
void IRQ175_Handler(void)
{
	IRQ_Fun.IRQ[RNG_RDREQ_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ176_Handler
  * @param  DMA0_IRQn 
  * @retval None
  */
void IRQ176_Handler(void)
{
	IRQ_Fun.IRQ[DMA0_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ177_Handler
  * @param  DMA1_IRQn 
  * @retval None
  */
void IRQ177_Handler(void)
{
	IRQ_Fun.IRQ[DMA1_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ178_Handler
  * @param  DMA2_IRQn 
  * @retval None
  */
void IRQ178_Handler(void)
{
	IRQ_Fun.IRQ[DMA2_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ179_Handler
  * @param  DMA3_IRQn 
  * @retval None
  */
void IRQ179_Handler(void)
{
	IRQ_Fun.IRQ[DMA3_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ180_Handler
  * @param  DMA4_IRQn 
  * @retval None
  */
void IRQ180_Handler(void)
{
	IRQ_Fun.IRQ[DMA4_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ181_Handler
  * @param  DMA5_IRQn 
  * @retval None
  */
void IRQ181_Handler(void)
{
	IRQ_Fun.IRQ[DMA5_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ182_Handler
  * @param  DMA6_IRQn 
  * @retval None
  */
void IRQ182_Handler(void)
{
	IRQ_Fun.IRQ[DMA6_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ183_Handler
  * @param  DMA7_IRQn 
  * @retval None
  */
void IRQ183_Handler(void)
{
	IRQ_Fun.IRQ[DMA7_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ184_Handler
  * @param  DMA8_IRQn 
  * @retval None
  */
void IRQ184_Handler(void)
{
	IRQ_Fun.IRQ[DMA8_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ185_Handler
  * @param  DMA9_IRQn 
  * @retval None
  */
void IRQ185_Handler(void)
{
	IRQ_Fun.IRQ[DMA9_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ186_Handler
  * @param  DMA10_IRQn 
  * @retval None
  */
void IRQ186_Handler(void)
{
	IRQ_Fun.IRQ[DMA10_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ187_Handler
  * @param  DMA11_IRQn 
  * @retval None
  */
void IRQ187_Handler(void)
{
	IRQ_Fun.IRQ[DMA11_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ188_Handler
  * @param  DMA12_IRQn 
  * @retval None
  */
void IRQ188_Handler(void)
{
	IRQ_Fun.IRQ[DMA12_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ189_Handler
  * @param  DMA13_IRQn 
  * @retval None
  */
void IRQ189_Handler(void)
{
	IRQ_Fun.IRQ[DMA13_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ190_Handler
  * @param  DMA14_IRQn 
  * @retval None
  */
void IRQ190_Handler(void)
{
	IRQ_Fun.IRQ[DMA14_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ191_Handler
  * @param  DMA15_IRQn 
  * @retval None
  */
void IRQ191_Handler(void)
{
	IRQ_Fun.IRQ[DMA15_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ192_Handler
  * @param  OCRV_IRQn 
  * @retval None
  */
void IRQ192_Handler(void)
{
	IRQ_Fun.IRQ[OCRV_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ193_Handler
  * @param  RAMPARITY_IRQn 
  * @retval None
  */
void IRQ193_Handler(void)
{
	IRQ_Fun.IRQ[RAMPARITY_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ194_Handler
  * @param  C1ERR_IRQn 
  * @retval None
  */
void IRQ194_Handler(void)
{
	IRQ_Fun.IRQ[C1ERR_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ195_Handler
  * @param  C1REC_IRQn 
  * @retval None
  */
void IRQ195_Handler(void)
{
	IRQ_Fun.IRQ[C1REC_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ196_Handler
  * @param  C1WUP_IRQn 
  * @retval None
  */
void IRQ196_Handler(void)
{
	IRQ_Fun.IRQ[C1WUP_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ197_Handler
  * @param  C1TRX_IRQn 
  * @retval None
  */
void IRQ197_Handler(void)
{
	IRQ_Fun.IRQ[C1TRX_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ198_Handler
  * @param  IIR0WFIFOEMP_IRQn 
  * @retval None
  */
void IRQ198_Handler(void)
{
	IRQ_Fun.IRQ[IIR0WFIFOEMP_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ199_Handler
  * @param  IIR0WFIFOFUL_IRQn 
  * @retval None
  */
void IRQ199_Handler(void)
{
	IRQ_Fun.IRQ[IIR0WFIFOFUL_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ200_Handler
  * @param  IIR1WFIFOEMP_IRQn 
  * @retval None
  */
void IRQ200_Handler(void)
{
	IRQ_Fun.IRQ[IIR1WFIFOEMP_IRQn].intHandle(&pData);
}

/**
  * @brief  IRQ201_Handler
  * @param  IIR1WFIFOFUL_IRQn 
  * @retval None
  */
void IRQ201_Handler(void)
{
	IRQ_Fun.IRQ[IIR1WFIFOFUL_IRQn].intHandle(&pData);
}       
                 
/**
  * @brief  register interrupt function according to  IRQn num.
  * @param  irq_num: it relates to irq handler 
  * @param	interrupt:interrupt server function
  * @retval regiseter status 
  */
int ISR_Register(IRQn_Type irq_num, void *interrupt)
{
	int res = ISR_SUCC;

	if(irq_num > IIR1WFIFOFUL_IRQn) return ISR_ERR;
	
	if(IRQ_Fun.IRQ[irq_num].IRQ_Flag)
	{
		return ISR_ERR;
	}
	else
	{		
		IRQ_Fun.IRQ[irq_num].IRQ_Flag = 1;
		IRQ_Fun.IRQ[irq_num].intHandle = (isrFun_t)interrupt;
		NVIC_DisableIRQ(irq_num);        
		NVIC_ClearPendingIRQ(irq_num); // clear  interrupt flag  
		NVIC_EnableIRQ(irq_num);
	}

	return res;
}
