#include "lvd.h"


/**
  * @brief  LVD lock.
  * @param  None
  * @retval None
  */
void LVD_Lock(void)
{
	LVD->LVIM &= ~LVD_LVIM_LVISEN_Msk;
}

/**
  * @brief  LVD unlock.
  * @param  None
  * @retval None
  */
void LVD_UnLock(void)
{
	LVD->LVIM |=  LVD_LVIM_LVISEN_Msk;
}

/**
  * @brief  Select LVD mode.
  * @param  LMod:
	*               LVD_MDInterrupt interrupt when LVD
	*               LVD_MDReset:reset when LVD
  * @retval None
  */
void LVD_Mode(uint8_t LMod)
{
	LVD_UnLock();
	if(LMod == LVD_MDInterrupt)
	{
		LVD->LVIS &= ~LVD_LVIS_LVIMD_Msk;			//⵽ѹж
	}
	else
	{
		LVD->LVIS |= LVD_LVIS_LVIMD_Msk;			//⵽ѹϵͳλ
	}
	LVD_Lock();
}

/**
  * @brief  Select LVD detect level.
  * @param  Level:
  *               LVD_DetectHigh: LVD detect high level
	*               LVD_DetectLow: LVD detect low level
  * @retval None
  */
void LVD_DetectLevel(uint8_t Level)
{
	LVD_UnLock();
	if(Level == LVD_DetectHigh)
	{
		LVD->LVIS &= ~LVD_LVIS_LVILV_Msk;			
	}
	else
	{
		LVD->LVIS |= LVD_LVIS_LVILV_Msk;			
	}
	LVD_Lock();
}

/**
  * @brief  return LVD detect voltage status.
  * @param  None:
	* @retval status:
  *            1:ԴѹVDDѹVLVD
  *            0:ԴѹVDDݼѹVLVDLVDΪOFF
  */
uint8_t LVD_StatusLevel(void)
{
	
	if(LVD->LVIM & LVD_LVIM_LVIF_Msk)		//ԴѹVDDѹVLVD
		return(1);
	else
		return(0);

}

/**
  * @brief  return LVD mask status.
  * @param  None:
	* @retval status:
  *            1:LVDЧ
  *            0:LVDЧ
  */
uint8_t LVD_StatusMask(void)
{
	
	if(LVD->LVIM & LVD_LVIM_LVIOMSK_Msk)		
		return(1);
	else
		return(0);

}

