/***********************************************************************************************************************
* Copyright (C) . All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : main.c
* Version      :
* Device(s)    : BAT32G439
* Tool-Chain   : MDK(armcc)
* Description  : This file is a template.
* Creation Date: 2022/5/30
***********************************************************************************************************************/

/***********************************************************************************************************************
Macro Definitions
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include <stdio.h>
#include "gpio_demo.h"
#include "delay_demo.h"
#include "rtc_demo.h"
#include "key_demo.h"
#include "cgc.h"
#include "pcbz.h"

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
extern uint32_t g_keyIntTaken;

void PCBZIO_Init()
{
    GPIO_InitTypeDef GPIO_InitStruct = {0};
    PCBZ_InitTypeDef PCBZ_InitStructure = {0};

    GPIO_PinAFConfig(GPIO_PORTE, GPIO_Pin_5, GROUP_AF_PCLBUZ0); // CLKBUZ0 can be alternative to any desired pins with PxxCFG register

    /*CLKBUZ0 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_5;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level = GPIO_Level_LOW;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTE, &GPIO_InitStruct);
	
	PCBZ_InitStructure.PCBZ_ChanSelect = PCBZ_CHANNEL_0;  //ѡclkbuz ͨ0
	PCBZ_InitStructure.PCBZ_ClkSource =  PCBZ_FMAIN;
	PCBZ_InitStructure.PCBZ_Freqscaler = PCBZ_FMAIN_3;	
	PCBZ_Init(&PCBZ_InitStructure);	
}

int main()
{
    uint32_t msCnt;     // count value of 1ms
    uint32_t i;
    //-----------------------------------------------------------------------
    // Initialize the ports to prevent the leakage current
    //-----------------------------------------------------------------------
		GPIO_PullUp_Enable(&PORT->PA, 0xFFFF);
		GPIO_PullUp_Enable(&PORT->PB, 0xFFFF);
		GPIO_PullUp_Enable(&PORT->PC, 0xFFFF);
		GPIO_PullUp_Enable(&PORT->PD, 0xFFFF);
		GPIO_Output_Enable(&PORT->PH, 0x001F);	// PH1/X1, PH2/X2, PH3/XT1, PH4/XT2 output low level

    //-----------------------------------------------------------------------
    // PE05/PCLBUZ0 output
    //-----------------------------------------------------------------------
    PCBZIO_Init();
    //-----------------------------------------------------------------------
    // Systick setting
    //-----------------------------------------------------------------------

    SystemCoreClockUpdate();
    msCnt = SystemCoreClock / 1000;
    SysTick_Config(msCnt);
    delay_init(SystemCoreClock);
		Led_Init();

    LED_ON;
    delayMS(500);                            // LED ON: 500ms for reconnect debugger
    LED_OFF;
    CGC_Hoco_Stop();
	
		CGC_LSEConfig(OSC_OSCILLATOR,OSC_NORMAL_POWER);
		CGC_LSE_CFG_AS_FCLK();   
    Rtc_InitDemo();
    RTC_Start();
	
    SysTick->CTRL  &= ~SysTick_CTRL_ENABLE_Msk;  /* Disable SysTick */

    //-----------------------------------------------------------------------
    // Sleep 4 times
    // PA0/KR0 falling edge wakeup system and blinky PC2 LED
    //-----------------------------------------------------------------------
    i = 0;

    while (1)
    {
        __STOP();           // Deep Sleep
        i++;

        if (i % 5 == 0)
        {
            PORT->PC ^= (1 << 2);   // PC2 toggle
        }

        if (g_keyIntTaken)
        {
            break;
        }
    }

    //-----------------------------------------------------------------------
    // Systick setting
    //-----------------------------------------------------------------------
    CGC_Hoco_Start();
    CGC_HSI_CFG_AS_FCLK();
    SysTick->CTRL  |= SysTick_CTRL_ENABLE_Msk;  /* Enable SysTick */


    //-----------------------------------------------------------------------
    // P70/KR0 falling edge wakeup system and blinky P71 LED
    //-----------------------------------------------------------------------
    while (1)
    {
        delayMS(250);
        LED_Toggle;
    }

}




