#include "iica_demo.h"
volatile uint8_t   g_iica_tx_end;             /* iica0 send data end */
volatile uint8_t   g_iica_rx_end;             /* iica0 receive data end */
uint16_t  g_iica_rx_cnt;                     /* iica1 receive data count */
uint16_t  g_iica_rx_len;                     /* iica1 receive data length */

#define _80_IICA_ADDRESS_COMPLETE                     (0x80U)
#define _00_IICA_MASTER_FLAG_CLEAR                    (0x00U)

void Iica0_Init(void)
{
    GPIO_InitTypeDef GPIO_InitStruct = {0};
    I2CA_InitTypeDef I2CA_InitStructure;

		GPIO_PinAFConfig(GPIO_PORTD, GPIO_Pin_0, GROUP_AF_SCLA0);
		GPIO_PinAFConfig(GPIO_PORTD, GPIO_Pin_1, GROUP_AF_SDAA0);
    /*SCLA0 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_0 ;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level  = GPIO_Level_LOW;
    GPIO_InitStruct.GPIO_PuPd   = GPIO_PuPd_UP;
    GPIO_InitStruct.GPIO_OType  = GPIO_OType_OD;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTD, &GPIO_InitStruct);

    /*SDAA0 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_1;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level  = GPIO_Level_LOW;
    GPIO_InitStruct.GPIO_PuPd   = GPIO_PuPd_UP;
    GPIO_InitStruct.GPIO_OType  = GPIO_OType_OD;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTD, &GPIO_InitStruct);

    I2CA_InitStructure.I2C_ClockSpeed = 800000;
    I2CA_InitStructure.I2C_Ack = I2CA_Ack_Enable;
    I2CA_InitStructure.I2C_DutyCycle = 50;
    I2CA_InitStructure.I2C_OwnAddress = 0xA0;
    I2CA_InitStructure.I2C_Mode = I2CA_Mode_SMBusSlave;
    I2CA_Init(I2CA0,&I2CA_InitStructure);


#ifdef I2CA_USING_INTERRUPT
    ISR_Register(IICA0_IRQn, iica0_interrupt);
    NVIC_EnableIRQ(IICA0_IRQn);                       //enable INTIICA interrupt flag
#endif
}
#if defined(BAT32G1XX_80PIN) || defined(BAT32G1XX_100PIN)
void Iica1_Init(void)
{
    GPIO_InitTypeDef GPIO_InitStruct = {0};
    I2CA_InitTypeDef I2CA_InitStructure;

		GPIO_PinAFConfig(GPIO_PORTB, GPIO_Pin_11, GROUP_AF_SCLA1);
		GPIO_PinAFConfig(GPIO_PORTB, GPIO_Pin_10, GROUP_AF_SDAA1);
    /*SCLA1 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_11;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level  = GPIO_Level_LOW;
    GPIO_InitStruct.GPIO_PuPd   = GPIO_PuPd_UP;
    GPIO_InitStruct.GPIO_OType  = GPIO_OType_OD;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTB, &GPIO_InitStruct);

    /*SDAA1 GPIO CONFIG*/
    GPIO_InitStruct.GPIO_Pin    = GPIO_Pin_10;
    GPIO_InitStruct.GPIO_Mode   = GPIO_Mode_OUT;
    GPIO_InitStruct.GPIO_Level  = GPIO_Level_LOW;
    GPIO_InitStruct.GPIO_PuPd   = GPIO_PuPd_UP;
    GPIO_InitStruct.GPIO_OType  = GPIO_OType_OD;
    GPIO_InitStruct.GPIO_Ctrl   = GPIO_Control_DIG;
    GPIO_Init(GPIO_PORTB, &GPIO_InitStruct);

    I2CA_InitStructure.I2C_ClockSpeed = 800000;
    I2CA_InitStructure.I2C_Ack = I2CA_Ack_Enable;
    I2CA_InitStructure.I2C_DutyCycle = 50;
    I2CA_InitStructure.I2C_OwnAddress = 0xA0;
    I2CA_InitStructure.I2C_Mode = I2CA_Mode_SMBusSlave;
    I2CA_Init(I2CA1,&I2CA_InitStructure);


#ifdef I2CA_USING_INTERRUPT
    ISR_Register(IICA1_IRQn, iica1_interrupt);
    NVIC_EnableIRQ(IICA1_IRQn);                       //enable INTIICA interrupt flag
#endif
}
#endif
/***********************************************************************************************************************
* Function Name: IICA_SlaveSend
* @brief  This function sends data as slave mode.
* @param  adr - send address
* @param  tx_buf - transfer buffer pointer
* @param  tx_num - buffer size
* @return None
***********************************************************************************************************************/
void IICA_SlaveSend(I2CASelect_TypeDef I2CAx,uint8_t adr, uint8_t *const tx_buf, uint16_t tx_num)
{
    g_iica_tx_end = 0;
    pData.len = tx_num;
    pData.data = tx_buf;
    pData.flag = INT_TX;
	if(I2CAx == I2CA0)	
	{
    IICA0->SVA = adr; /* slave address */
	}
	#if defined(BAT32G1XX_80PIN) || defined(BAT32G1XX_100PIN)
	else if(I2CAx == I2CA1)
	{
		IICA1->SVA = adr; /* slave address */
	}
	#endif
}
/***********************************************************************************************************************
* Function Name: IICA_SlaveReceive
* @brief  This function receives data as slave mode.
* @param  adr - send address
* @param  tx_buf - receive buffer pointer
* @param  rx_num - buffer size
* @return None
***********************************************************************************************************************/
void IICA_SlaveReceive(I2CASelect_TypeDef I2CAx,uint8_t adr, uint8_t *const rx_buf, uint16_t rx_num)
{
    g_iica_rx_end = 0;
    g_iica_rx_len = 0;
    g_iica_rx_cnt = rx_num;
    pData.len = 0;
    pData.data = rx_buf;
    pData.flag = INT_RX;
		if(I2CAx == I2CA0)	
		{
			IICA0->SVA = adr; /* slave address */
		}
		#if defined(BAT32G1XX_80PIN) || defined(BAT32G1XX_100PIN)
		else if(I2CAx == I2CA1)
		{
			IICA1->SVA = adr; /* slave address */
		}
		#endif
}




/***********************************************************************************************************************
* Function Name: iica0_slavehandler
* @brief   This function is IICA0 slave handler.
* @param  None
* @return None
***********************************************************************************************************************/
#if 0
static void iica0_slavehandler(void *msg)
{
    ATE_FRAME_t *pFrame = (ATE_FRAME_t *)msg;

    if (IICA0->IICS0 & IICA0_IICS0_SPD_Msk)  //check stop condition
    {
        IICA0->IICCTL0 &= ~IICA0_IICCTL00_SPIE_Msk; /* SPIE0 = 0: disable */

        if (pFrame->flag & _80_IICA_ADDRESS_COMPLETE)
        {
            if (pFrame->flag & 0x04U)   // send flag
            {
                g_iica_tx_end = 1; //slave_sendend
            }

            if (pFrame->flag & 0x02U)
            {
                g_iica_rx_end = 1; //slave_receiveend

                pFrame->len = 0;

            }
        }

        pFrame->flag = 1U;
    }
    else
    {
        if ((pFrame->flag & _80_IICA_ADDRESS_COMPLETE) == 0U) //write address uncompleted
        {
            if (IICA0->IICS0 & IICA0_IICS0_COI_Msk) //receive address is same with slave address
            {
                IICA0->IICCTL0 |= IICA0_IICCTL00_SPIE_Msk; //SPIE0 = 1: enable
                pFrame->flag = _80_IICA_ADDRESS_COMPLETE;

                if (IICA0->IICS0 & IICA0_IICS0_TRC_Msk)  // TRC0 == 1 sendding status
                {
                    IICA0->IICCTL0 |= IICA0_IICCTL00_WTIM_Msk;  //interrupt request is generated at the ninth clock's falling edge

                    if (pFrame->len > 0U)
                    {
                        IICA0->IICA = *pFrame->data;
                        pFrame->data++;
                        pFrame->len--;
                    }
                    else
                    {
                        g_iica_tx_end = 1;// slave send finished
                        IICA0->IICCTL0 |= IICA0_IICCTL00_WREL_Msk;  // cancel wait
                    }
                }
                else  //receiving status
                {
                    IICA0->IICCTL0 &= ~IICA0_IICCTL00_WTIM_Msk;    // interrupt request is generated at the eighth clock's falling edge
                    IICA0->IICCTL0 |= IICA0_IICCTL00_WREL_Msk;     // cancel wait
                }
            }
            else
            {
                //              iica_master_error(STOP_ERR);//slave address error
            }
        }
        else   //address matching completed
        {
            if (IICA0->IICS0 & IICA0_IICS0_TRC_Msk)  // sending status
            {
                pFrame->flag |= 4U;   //send flag

                if ((0U == (IICA0->IICS0 & IICA0_IICS0_ACKD_Msk)) && (pFrame->len != 0U))
                {
                    //                  iica_master_error(NACK);//slave send error
                }
                else
                {
                    if (pFrame->len > 0U)
                    {
                        IICA0->IICA = *pFrame->data;
                        pFrame->data++;
                        pFrame->len--;
                    }
                    else
                    {
                        g_iica_tx_end = 1;                          // slave send finished
                        IICA0->IICCTL0 |= IICA0_IICCTL00_WREL_Msk;  //WREL0 = 1U: cancel wait
                    }
                }
            }
            else  // receiving status
            {
                pFrame->flag |= 2U;  //receive flag

                if (pFrame->len < g_iica_rx_cnt)
                {
                    *pFrame->data = IICA0->IICA;
                    pFrame->data++;
                    pFrame->len++;

                    if (g_iica_rx_cnt == pFrame->len)
                    {
                        IICA0->IICCTL0 |= IICA0_IICCTL00_WTIM_Msk;   // WTIM0 = 1:  interrupt request is generated at the ninth clock's falling edge
                        IICA0->IICCTL0 |= IICA0_IICCTL00_WREL_Msk;   // WREL0 = 1U: cancel wait
                        g_iica_rx_end = 1;                           // slave receive finished
                    }
                    else
                    {
                        IICA0->IICCTL0 |= IICA0_IICCTL00_WREL_Msk;   // WREL0 = 1U: cancel wait
                    }
                }
                else
                {
                    IICA0->IICCTL0 |=  IICA0_IICCTL00_WREL_Msk;   // WREL0 = 1U: cancel wait
                }
            }
        }
    }
}
#if defined(BAT32G1XX_80PIN) || defined(BAT32G1XX_100PIN)
static void iica1_slavehandler(void *msg)
{
    ATE_FRAME_t *pFrame = (ATE_FRAME_t *)msg;

    if (IICA1->IICS0 & IICA1_IICS1_SPD_Msk)  //check stop condition
    {
        IICA1->IICCTL0 &= ~IICA1_IICCTL10_SPIE_Msk; /* SPIE0 = 0: disable */

        if (pFrame->flag & _80_IICA_ADDRESS_COMPLETE)
        {
            if (pFrame->flag & 0x04U)   // send flag
            {
                g_iica_tx_end = 1; //slave_sendend
            }

            if (pFrame->flag & 0x02U)
            {
                g_iica_rx_end = 1; //slave_receiveend

                pFrame->len = 0;

            }
        }

        pFrame->flag = 1U;
    }
    else
    {
        if ((pFrame->flag & _80_IICA_ADDRESS_COMPLETE) == 0U) //write address uncompleted
        {
            if (IICA1->IICS0 & IICA1_IICS1_COI_Msk) //receive address is same with slave address
            {
                IICA1->IICCTL0 |= IICA1_IICCTL10_SPIE_Msk; //SPIE0 = 1: enable
                pFrame->flag = _80_IICA_ADDRESS_COMPLETE;

                if (IICA1->IICS0 & IICA1_IICS1_TRC_Msk)  // TRC0 == 1 sendding status
                {
                    IICA1->IICCTL0 |= IICA1_IICCTL10_WTIM_Msk;  //interrupt request is generated at the ninth clock's falling edge

                    if (pFrame->len > 0U)
                    {
                        IICA1->IICA = *pFrame->data;
                        pFrame->data++;
                        pFrame->len--;
                    }
                    else
                    {
                        g_iica_tx_end = 1;// slave send finished
                        IICA1->IICCTL0 |= IICA1_IICCTL10_WREL_Msk;  // cancel wait
                    }
                }
                else  //receiving status
                {
                    IICA1->IICCTL0 &= ~IICA1_IICCTL10_WTIM_Msk;    // interrupt request is generated at the eighth clock's falling edge
                    IICA1->IICCTL0 |= IICA1_IICCTL10_WREL_Msk;     // cancel wait
                }
            }
            else
            {
                //              iica_master_error(STOP_ERR);//slave address error
            }
        }
        else   //address matching completed
        {
            if (IICA1->IICS0 & IICA1_IICS1_TRC_Msk)  // sending status
            {
                pFrame->flag |= 4U;   //send flag

                if ((0U == (IICA1->IICS0 & IICA1_IICS1_ACKD_Msk)) && (pFrame->len != 0U))
                {
                    //                  iica_master_error(NACK);//slave send error
                }
                else
                {
                    if (pFrame->len > 0U)
                    {
                        IICA1->IICA = *pFrame->data;
                        pFrame->data++;
                        pFrame->len--;
                    }
                    else
                    {
                        g_iica_tx_end = 1;                          // slave send finished
                        IICA1->IICCTL0 |= IICA1_IICCTL10_WREL_Msk;  //WREL0 = 1U: cancel wait
                    }
                }
            }
            else  // receiving status
            {
                pFrame->flag |= 2U;  //receive flag

                if (pFrame->len < g_iica_rx_cnt)
                {
                    *pFrame->data = IICA1->IICA;
                    pFrame->data++;
                    pFrame->len++;

                    if (g_iica_rx_cnt == pFrame->len)
                    {
                        IICA1->IICCTL0 |= IICA1_IICCTL10_WTIM_Msk;   // WTIM0 = 1:  interrupt request is generated at the ninth clock's falling edge
                        IICA1->IICCTL0 |= IICA1_IICCTL10_WREL_Msk;   // WREL0 = 1U: cancel wait
                        g_iica_rx_end = 1;                           // slave receive finished
                    }
                    else
                    {
                        IICA1->IICCTL0 |= IICA1_IICCTL10_WREL_Msk;   // WREL0 = 1U: cancel wait
                    }
                }
                else
                {
                    IICA1->IICCTL0 |=  IICA1_IICCTL10_WREL_Msk;   // WREL0 = 1U: cancel wait
                }
            }
        }
    }
}
#endif
#else
uint8_t addrMatchrx = 0;
uint8_t addrMatchtx = 0;
uint8_t Stop_count = 0;
__IOM uint8_t Reg = 0;
static void iica0_slavehandler(void *msg)
{
    ATE_FRAME_t *pFrame = (ATE_FRAME_t *)msg;

    /* Control for stop condition */
    if (IICA0->IICS0 & IICA0_IICS0_SPD_Msk)
    {
        /* Get stop condition */
        Stop_count++;

        if (pFrame->flag == INT_TX && Stop_count == 2)  // send flag
        {
            IICA0->IICCTL0 &= ~IICA0_IICCTL00_SPIE_Msk; /* SPIE0 = 0: disable */
            g_iica_tx_end = 1; //slave_sendend
            addrMatchtx = 0;
            Stop_count = 0;
        }

        if (pFrame->flag == INT_RX)
        {
            IICA0->IICCTL0 &= ~IICA0_IICCTL00_SPIE_Msk; /* SPIE0 = 0: disable */
            g_iica_rx_end = 1; //slave_receiveend
            g_iica_rx_len = pFrame->len;
            addrMatchrx = 0;
            Stop_count = 0;
        }
    }
    else
    {
        if (pFrame->flag == INT_RX)
        {
            if (!addrMatchrx && IICA0->IICS0 & IICA0_IICS0_COI_Msk)   //ַƥ
            {
                addrMatchrx = 1;

                IICA0->IICCTL0 |= IICA0_IICCTL00_SPIE_Msk; /* SPIE0 = 1: enable */

                IICA0->IICCTL0 |=  IICA0_IICCTL00_ACKE_Msk;   /* ACKE0 = 1U: enable acknowledgment */
                /* interrupt request is generated at the eighth clock's falling edge */
                IICA0->IICCTL0 &= ~IICA0_IICCTL00_WTIM_Msk;

                /* cancel wait */
                IICA0->IICCTL0 |= IICA0_IICCTL00_WREL_Msk;
            }
            else
            {
                if (pFrame->len < g_iica_rx_cnt)
                {
                    *pFrame->data = IICA0->IICA;
                    pFrame->data++;
                    pFrame->len++;

                    IICA0->IICCTL0 |= IICA0_IICCTL00_WREL_Msk;   // WREL0 = 1U: cancel wait

                    if (g_iica_rx_cnt == pFrame->len)
                    {
                        IICA0->IICCTL0 |= IICA0_IICCTL00_WTIM_Msk;   // WTIM0 = 1:  interrupt request is generated at the ninth clock's falling edge
                        g_iica_rx_end = 1;                           // slave receive finished
                        g_iica_rx_len = pFrame->len;
                        addrMatchrx = 0;
                    }
                }
                else
                {
                    IICA0->IICCTL0 |= IICA0_IICCTL00_WTIM_Msk;   // WTIM0 = 1:  interrupt request is generated at the ninth clock's falling edge
                    IICA0->IICCTL0 |=  IICA0_IICCTL00_WREL_Msk;   // WREL0 = 1U: cancel wait
                }
            }
        }

        if (pFrame->flag == INT_TX)
        {
            if ((addrMatchtx < 2) && (IICA0->IICS0 & IICA0_IICS0_COI_Msk)) //ַƥ
            {
                addrMatchtx ++;

                if (addrMatchtx == 1)
                {
                    IICA0->SVA |= 0x01;    //һȶ
                }
                else if (addrMatchtx == 2)
                {
                    Reg = IICA0->IICA;
                    IICA0->SVA &= ~0x01;
                }

                if (!(IICA0->IICCTL0 & IICA0_IICCTL00_SPIE_Msk))
                {
                    /* SPIE0 = 1: enable I2CA */
                    IICA0->IICCTL0 |= IICA0_IICCTL00_SPIE_Msk;
                }

                /* Sending or receiving */
                if (IICA0->IICS0 & IICA0_IICS0_TRC_Msk)    //send status
                {
                    IICA0->IICCTL0 |= IICA0_IICCTL00_WTIM_Msk; //9ʱӣʱΪ͵ƽ

                }
                else
                {
                    IICA0->IICCTL0 &= ~IICA0_IICCTL00_WTIM_Msk;    // interrupt request is generated at the eighth clock's falling edge
                    IICA0->IICCTL0 |= IICA0_IICCTL00_WREL_Msk;     // cancel wait
                }
            }
            else
            {
                if (IICA0->IICS0 & IICA0_IICS0_TRC_Msk)  /* TRC0 == 1 */
                {
                    if (pFrame->len > 0U)
                    {
                        IICA0->IICA = *pFrame->data;
                        pFrame->data++;
                        pFrame->len--;
                    }
                    else
                    {
                        IICA0->IICA = 0xFF;
                        g_iica_tx_end = 1;
                    }
                }
            }

        }

    }
}
#if defined(BAT32G1XX_80PIN) || defined(BAT32G1XX_100PIN)
static void iica1_slavehandler(void *msg)
{
    ATE_FRAME_t *pFrame = (ATE_FRAME_t *)msg;

    /* Control for stop condition */
    if (IICA1->IICS0 & IICA1_IICS1_SPD_Msk)
    {
        /* Get stop condition */
        Stop_count++;

        if (pFrame->flag == INT_TX && Stop_count == 2)  // send flag
        {
            IICA1->IICCTL0 &= ~IICA1_IICCTL10_SPIE_Msk; /* SPIE0 = 0: disable */
            g_iica_tx_end = 1; //slave_sendend
            addrMatchtx = 0;
            Stop_count = 0;
        }

        if (pFrame->flag == INT_RX)
        {
            IICA1->IICCTL0 &= ~IICA1_IICCTL10_SPIE_Msk; /* SPIE0 = 0: disable */
            g_iica_rx_end = 1; //slave_receiveend
            g_iica_rx_len = pFrame->len;
            addrMatchrx = 0;
            Stop_count = 0;
        }
    }
    else
    {
        if (pFrame->flag == INT_RX)
        {
            if (!addrMatchrx && IICA1->IICS0 & IICA1_IICS1_COI_Msk)   //ַƥ
            {
                addrMatchrx = 1;

                IICA1->IICCTL0 |= IICA1_IICCTL10_SPIE_Msk; /* SPIE0 = 1: enable */

                IICA1->IICCTL0 |=  IICA1_IICCTL10_ACKE_Msk;   /* ACKE0 = 1U: enable acknowledgment */
                /* interrupt request is generated at the eighth clock's falling edge */
                IICA1->IICCTL0 &= ~IICA1_IICCTL10_WTIM_Msk;

                /* cancel wait */
                IICA1->IICCTL0 |= IICA1_IICCTL10_WREL_Msk;
            }
            else
            {
                if (pFrame->len < g_iica_rx_cnt)
                {
                    *pFrame->data = IICA1->IICA;
                    pFrame->data++;
                    pFrame->len++;

                    IICA1->IICCTL0 |= IICA1_IICCTL10_WREL_Msk;   // WREL0 = 1U: cancel wait

                    if (g_iica_rx_cnt == pFrame->len)
                    {
                        IICA1->IICCTL0 |= IICA1_IICCTL10_WTIM_Msk;   // WTIM0 = 1:  interrupt request is generated at the ninth clock's falling edge
                        g_iica_rx_end = 1;                           // slave receive finished
                        g_iica_rx_len = pFrame->len;
                        addrMatchrx = 0;
                    }
                }
                else
                {
                    IICA1->IICCTL0 |= IICA1_IICCTL10_WTIM_Msk;   // WTIM0 = 1:  interrupt request is generated at the ninth clock's falling edge
                    IICA1->IICCTL0 |=  IICA1_IICCTL10_WREL_Msk;   // WREL0 = 1U: cancel wait
                }
            }
        }

        if (pFrame->flag == INT_TX)
        {
            if ((addrMatchtx < 2) && (IICA1->IICS0 & IICA1_IICS1_COI_Msk)) //ַƥ
            {
                addrMatchtx ++;

                if (addrMatchtx == 1)
                {
                    IICA1->SVA |= 0x01;    //һȶ
                }
                else if (addrMatchtx == 2)
                {
                    Reg = IICA1->IICA;
                    IICA1->SVA &= ~0x01;
                }

                if (!(IICA1->IICCTL0 & IICA1_IICCTL10_SPIE_Msk))
                {
                    /* SPIE0 = 1: enable I2CA */
                    IICA1->IICCTL0 |= IICA1_IICCTL10_SPIE_Msk;
                }

                /* Sending or receiving */
                if (IICA1->IICS0 & IICA1_IICS1_TRC_Msk)    //send status
                {
                    IICA1->IICCTL0 |= IICA1_IICCTL10_WTIM_Msk; //9ʱӣʱΪ͵ƽ

                }
                else
                {
                    IICA1->IICCTL0 &= ~IICA1_IICCTL10_WTIM_Msk;    // interrupt request is generated at the eighth clock's falling edge
                    IICA1->IICCTL0 |= IICA1_IICCTL10_WREL_Msk;     // cancel wait
                }
            }
            else
            {
                if (IICA1->IICS0 & IICA1_IICS1_TRC_Msk)  /* TRC0 == 1 */
                {
                    if (pFrame->len > 0U)
                    {
                        IICA1->IICA = *pFrame->data;
                        pFrame->data++;
                        pFrame->len--;
                    }
                    else
                    {
                        IICA1->IICA = 0xFF;
                        g_iica_tx_end = 1;
                    }
                }
            }

        }

    }
}
#endif

#endif
void iica0_interrupt(void *msg)
{
    NVIC_ClearPendingIRQ(IICA0_IRQn);
    //    IICA0_Clear_Wakeup();
    //  if ((IICA->IICS0 & 0x80) == 0x80U)
    //  {
    //      iica0_masterhandler((void *)msg);
    //  }
    //  else
    {
        iica0_slavehandler((void *)msg);
    }
}

#if defined(BAT32G1XX_80PIN) || defined(BAT32G1XX_100PIN)
void iica1_interrupt(void *msg)
{
    NVIC_ClearPendingIRQ(IICA1_IRQn);
    //    IICA0_Clear_Wakeup();
    //  if ((IICA->IICS0 & 0x80) == 0x80U)
    //  {
    //      iica0_masterhandler((void *)msg);
    //  }
    //  else
    {
        iica1_slavehandler((void *)msg);
    }
}
#endif
